Processing API
=============

The ``processing`` module contains functions for processing DEMs and extracting hydro-topographic features.

.. automodule:: hydro_topo_features.processing
   :members:
   :undoc-members:
   :show-inheritance:

Prepare Data
-----------

.. automodule:: hydro_topo_features.processing.prepare_data
   :members:
   :undoc-members:
   :show-inheritance:

Burn DEM
--------

.. automodule:: hydro_topo_features.processing.burn_dem
   :members:
   :undoc-members:
   :show-inheritance:

Derive Products
-------------

.. automodule:: hydro_topo_features.processing.derive_products
   :members:
   :undoc-members:
   :show-inheritance:

Functions:

- ``get_osm_hand``: Compute Height Above Nearest Drainage (HAND) using OSM water features
- ``get_slope``: Compute slope from DEM
- ``get_edtw``: Compute Euclidean Distance to Water (EDTW) 